@@ -1,4 +1,4 @@
-from janis_assistant.main import fromjanis
+# from janis_assistant.main import fromjanis
 from janis_assistant.management.filescheme import (
     FileScheme,
     LocalFileScheme,
