@@ -242,9 +242,7 @@ def add_spider_args(parser):
         help="Adds statements to help find why a tool isn't appearing in the toolbox",
     )
     parser.add_argument(
-        "--all",
-        action="store_true",
-        help="Print all tools in alphabetical order",
+        "--all", action="store_true", help="Print all tools in alphabetical order",
     )
 
 
