@@ -288,8 +288,9 @@ class WorkflowManager:
 
         jc = metadb.prepared_job
         PreparedJob._instance = jc
+
         metadb.containertype = jc._container.__name__
-        metadb.containerversion = jc._container.test_available_by_getting_version()
+        metadb.containerversion = jc._container.test_available_by_getting_version(jc.template.template.setup_container_command())
 
         self.database.submission_metadata.save_changes()
 
@@ -310,6 +311,10 @@ class WorkflowManager:
             "--foreground",
             self.execution_dir,
         ]
+
+        if jc.template.template.prejanis_hook() is not None:
+            command = [f"{jc.template.template.prejanis_hook()};"] + command
+
         scriptdir = self.get_path_for_component(self.WorkflowManagerPath.configuration)
         logdir = self.get_path_for_component(self.WorkflowManagerPath.logs)
 
@@ -1093,13 +1098,10 @@ Kind regards,
         out_job_path = os.path.join(output_dir, "job.yaml")
         out_run_path = os.path.join(output_dir, "run.sh")
 
-        if os.path.exists(out_job_path) and not force_write:
-            Logger.warn(
-                f"There was already a job file at '{out_job_path}', skipping write"
-            )
-        else:
-            with open(out_job_path, "w+") as f:
-                f.write(s)
+        # mfranklin 2020-01-22: Always force overrite the job.yaml, because it gets re-parsed in when
+        # janis runs in a detatched mode (in the background with: janis run -B <wf>)
+        with open(out_job_path, "w+") as f:
+            f.write(s)
 
         if prepared_job._workflow_reference and isinstance(
             prepared_job._workflow_reference, str
@@ -1434,6 +1436,13 @@ janis run \\
                     f"Couldn't find expected output with tag {out.id_}, found outputs ({', '.join(eoutkeys)}"
                 )
                 continue
+
+            # not None but just some empty values like an empty list or empty string
+            if not eout:
+                return Logger.critical(
+                    f"Engine '{self.engine.id()}' didn't return {out.id_} outputs for Janis to copy, skipping"
+                )
+
             originalfile, newfilepath = self.copy_output(
                 fs=self.filescheme,
                 output_dir=submission.output_dir,
