@@ -1,4 +1,5 @@
 import sys
+import os
 from abc import ABC, abstractmethod
 from datetime import datetime
 from typing import Type, Optional, List, Dict
@@ -190,20 +191,6 @@ class EnvironmentTemplate(ABC):
     Kind regards,
     
     - Janis
-        <p>
-            The workflow '{wfname}' ({wid}) moved to the '{status}' status.
-        </p>
-        <ul>
-            <li>Task directory: <code>{tdir}</code></li>
-            <li>Execution directory: <code>{exdir}</code></li>
-        </ul>
-        
-        {progress_and_header}
-        
-        <em>Sent at {timestamp}</em>
-        
-        Kind regards,
-        - Janis
         """
 
         progress_and_header = ""
@@ -237,6 +224,9 @@ class EnvironmentTemplate(ABC):
         """
         return test_command
 
+    def setup_container_command(self):
+        return None
+
 
 class SingularityEnvironmentTemplate(EnvironmentTemplate, ABC):
     def __init__(
