@@ -20,6 +20,9 @@ class SlurmSingularityTemplate(SingularityEnvironmentTemplate):
         "can_run_in_foreground",
         "run_in_background",
         "intermediate_execution_dir",
+        "max_workflow_time",
+        "sbatch",
+        "catch_slurm_errors",
     ]
 
     def __init__(
@@ -222,3 +225,6 @@ class SlurmSingularityTemplate(SingularityEnvironmentTemplate):
             logsdir=logsdir,
             **kwargs,
         )
+
+    def setup_container_command(self):
+        return self.singularity_load_instructions
